@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -17,7 +17,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 import mobius
 import pymobius
-import binascii
 import traceback
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -58,21 +57,21 @@ class Ant (object):
 
     for password in self.__passwords:
       try:
-        value = mobius.crypt.hash_digest ('sha1', password.decode ('utf-8').encode ('utf-16-le'))
-        turing.set_hash ('sha1.utf16', binascii.hexlify (value), password)
-      except Exception, e:
-        mobius.core.logf ('WRN ant.turing.add_passwords_to_database: ' + str (e) + ' ' + traceback.format_exc ())
+        value = mobius.crypt.hash_digest ('sha1', password.encode ('utf-16-le'))
+        turing.set_hash ('sha1.utf16', mobius.encoder.hexstring (value), password)
+      except Exception as e:
+        mobius.core.logf ('WRN ' + str (e) + ' ' + traceback.format_exc ())
 
       try:
         value = mobius.os.win.hash_nt (password)
-        turing.set_hash ('nt', binascii.hexlify (value), password)
-      except Exception, e:
-        mobius.core.logf ('WRN ant.turing.add_passwords_to_database: ' + str (e) + ' ' + traceback.format_exc ())
+        turing.set_hash ('nt', mobius.encoder.hexstring (value), password)
+      except Exception as e:
+        mobius.core.logf ('WRN ' + str (e) + ' ' + traceback.format_exc ())
 
     transaction.commit ()
 
-    mobius.core.logf ('INF ant.turing: %d password(s) added to database' % len (self.__passwords))
-    
+    mobius.core.logf ('INF %d password(s) added to database' % len (self.__passwords))
+
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief Event <i>on_add_password</i>: Process password object
   # @param ant Mediator ant object
